@@ -40,10 +40,11 @@ extern struct display *display, *displays;
 
 extern int  force_vt;
 extern int  all_norefresh;	/* => display */
-extern int  ZombieKey;
+extern int  ZombieKey_destroy, ZombieKey_resurrect;
 extern int  real_uid, real_gid;
 extern time_t Now;
 extern struct NewWindow nwin_default;	/* for ResetWindow() */
+extern int  nversion;
 
 int maxwidth;			/* maximum of all widths so far */
 
@@ -138,23 +139,41 @@ WinProcess(bufpp, lenp)
 char **bufpp;
 int *lenp;
 {
-  int addlf, l2, f, *ilen, l = *lenp;
+  int addlf, l2 = 0, f, *ilen, l = *lenp;
   char *ibuf, *p, *buf = *bufpp;
   
   fore = D_fore;
   /* if w_wlock is set, only one user may write, else we check acls */
   if (fore->w_ptyfd < 0)
     {
-      SetCurr(fore);
-      Special('\007');
       while ((*lenp)-- > 0)
         {
-	  if (*(*bufpp)++ == ZombieKey)
+	  f = *(*bufpp)++;
+	  if (f == ZombieKey_destroy)
 	    {
 	      debug2("Turning undead: %d(%s)\n", fore->w_number, fore->w_title);
 	      KillWindow(fore);
+	      l2--;
 	      break;
 	    }
+	  if (f == ZombieKey_resurrect)
+	    {
+	      SetCurr(fore);
+
+	      debug1("Resurrecting Zombie: %d\n", fore->w_number);
+	      LineFeed(2);
+	      RemakeWindow(fore);
+	      l2++;
+	      break;
+	    }
+	}
+      if (!l2)
+        {
+	  char b1[10], b2[10];
+
+	  b1[AddXChar(b1, ZombieKey_destroy)] = '\0';
+	  b2[AddXChar(b2, ZombieKey_resurrect)] = '\0';
+	  Msg(0, "Press %s to destroy or %s to resurrect window", b1, b2);
 	}
       *bufpp += *lenp;
       *lenp = 0;
@@ -364,16 +383,47 @@ register struct win *p;
   p->w_x = p->w_y = 0;
   p->w_state = LIT;
   p->w_StringType = NONE;
-  p->w_ss = 0;
-  p->w_Charset = G0;
-  p->w_CharsetR = G2;
   bzero(p->w_tabs, p->w_width);
   for (i = 8; i < p->w_width; i += 8)
     p->w_tabs[i] = 1;
+  ResetCharsets(p);
+}
+
+void
+ResetCharsets(p)
+register struct win *p;
+{
+  int i;
+
+  p->w_Charset = G0;
+  p->w_CharsetR = G2;
   for (i = G0; i <= G3; i++)
     p->w_charsets[i] = ASCII;
-  p->w_gr = 0;
-  p->w_c1 = 1;
+  p->w_gr = nwin_default.gr;
+  p->w_c1 = nwin_default.c1;
+  p->w_ss = 0;
+#ifdef KANJI
+  switch(p->w_kanji)
+    {
+    case SJIS:
+      p->w_CharsetR = G1;
+      p->w_charsets[G1] = KANA;
+      p->w_gr = 1;
+      p->w_c1 = 0;
+      break;
+    case EUC:
+      p->w_CharsetR = G1;
+      p->w_charsets[G1] = KANJI;
+      p->w_charsets[G2] = KANA;
+      p->w_gr = 1;
+      p->w_c1 = 1;
+      break;
+    default:
+      break;
+    }
+#endif
+  p->w_Font = p->w_charsets[p->w_Charset];
+  p->w_FontR = p->w_charsets[p->w_CharsetR];
 }
 
 static void
@@ -700,7 +750,10 @@ skip:	      if (--len == 0)
 	      break;
 	    default:
 	      if (Special(c))
-		break;
+	        {
+		  curr->w_state = LIT;
+		  break;
+		}
 	      debug1("not special. c = %x\n", c);
 	      if (c >= ' ' && c <= '/')
 		{
@@ -1428,6 +1481,15 @@ int c, intermediate;
 	    }
 	}
       break;
+    case '>':
+      switch (c)
+	{
+	case 'c':	/* secondary DA */
+	  if (a1 == 0)
+	    Report("\033[>%d;%d;0c", 83, nversion);	/* 83 == 'S' */
+	  break;
+	}
+      break;
     }
 }
 
