@@ -71,6 +71,7 @@ struct display
   int	d_cursorkeys;		/* application cursorkeys flag */
   int	d_revvid;		/* reverse video */
   int	d_curinv;		/* cursor invisible */
+  int	d_hstatus;		/* hardstatus used */
   int	d_lp_missing;		/* last character on bot line missing */
   int	d_lp_image;		/* missing image */
   int	d_lp_attr;		/* missing attr */
@@ -159,6 +160,7 @@ extern struct display TheDisplay;
 #define D_cursorkeys	DISPLAY(d_cursorkeys)
 #define D_revvid	DISPLAY(d_revvid)
 #define D_curinv	DISPLAY(d_curinv)
+#define D_hstatus	DISPLAY(d_hstatus)
 #define D_lp_missing	DISPLAY(d_lp_missing)
 #define D_lp_image	DISPLAY(d_lp_image)
 #define D_lp_attr	DISPLAY(d_lp_attr)
