@@ -53,7 +53,7 @@ char *myname;
   printf("-f           Flow control on, -fn = off, -fa = auto.\n");
   printf("-h lines     Set the size of the scrollback history buffer.\n");
   printf("-i           Interrupt output sooner when flow control is on.\n");
-#ifdef LOGOUTOK
+#if defined(LOGOUTOK) && defined(UTMPOK)
   printf("-l           Login mode on (update %s), -ln = off.\n", UTMPFILE);
 #endif
   printf("-list        or -ls. Do nothing, just list our SockDir.\n");
