@@ -59,7 +59,8 @@ extern int use_hardstatus, visual_bell;
 extern char *printcmd;
 extern int default_startup;
 extern int slowpaste, defobuflimit;
-extern int ZombieKey;
+extern int ZombieKey_destroy;
+extern int ZombieKey_resurrect;
 #ifdef AUTO_NUKE
 extern int defautonuke;
 #endif
@@ -142,9 +143,7 @@ extern int nethackflag;
 #endif
 
 
-struct win *wtab[MAXWIN];	/* window table */
-struct action ktab[256];	/* command key translation table */
-
+struct win *wtab[MAXWIN];	/* window table, should be dynamic */
 
 #ifdef MULTIUSER
 extern char *multi;
@@ -156,14 +155,16 @@ char Password[30];
 
 struct plop plop_tab[MAX_PLOP_DEFS];
 
-#ifdef PTYMODE
-int TtyMode = PTYMODE;
-#else
-int TtyMode = 0622;
+#ifndef PTYMODE
+# define PTYMODE 0622
 #endif
+
+int TtyMode = PTYMODE;
 int hardcopy_append = 0;
 int all_norefresh = 0;
 
+struct action ktab[256];	/* command key translation table */
+
 #ifdef MAPKEYS
 struct action umtab[KMAP_KEYS+KMAP_AKEYS+KMAP_EXT];
 struct action dmtab[KMAP_KEYS+KMAP_AKEYS+KMAP_EXT];
@@ -365,6 +366,7 @@ int ilen;
 }
 #endif
 
+
 void
 ProcessInput(ibuf, ilen)
 char *ibuf;
@@ -444,8 +446,10 @@ int ilen;
 		debug1(" - action %d\n", i);
 		fore = D_fore;
 		act = 0;
+#ifdef COPY_PASTE
 		if (InMark())
 		  act = &mmtab[i];
+#endif
 		if ((!act || act->nr == RC_ILLEGAL) && !D_mapdefault)
 		  act = &umtab[i];
 		D_mapdefault = 0;
@@ -749,18 +753,26 @@ int key;
 #endif
       break;
     case RC_ZOMBIE:
-      if (!(s = *args))
-        {
-	  ZombieKey = 0;
-	  break;
-	}
-      if (!(s = ParseChar(s, &ch)) || *s)
-        {
-	  Msg(0, "%s:zombie: one character expected.", rc_name);
-	  break;
-	}
-      ZombieKey = ch;
-      break;
+      {
+        char ch2 = 0;
+
+	if (!(s = *args))
+	  {
+	    ZombieKey_destroy = 0;
+	    break;
+	  }
+	if (!(s = ParseChar(s, &ch)) || *s)
+	  {
+	    if (!s || !(s = ParseChar(s, &ch2)) || *s)
+	      {
+		Msg(0, "%s:zombie: one or two characters expected.", rc_name);
+		break;
+	      }
+	  }
+	ZombieKey_destroy = ch;
+	ZombieKey_resurrect = ch2;
+	break;
+      }
     case RC_WALL:
       for (n = 0, s = *args; args[n]; n++)
         {
@@ -799,8 +811,7 @@ int key;
 	    struct display *nd;
 	    struct user *u;
 
-	    args[0][n] = '\0';
-	    if (!*args[0])
+	    if (!n)
 	      u = D_user;
 	    else
 	      for (u = users; u; u = u->u_next)
@@ -831,7 +842,6 @@ int key;
 	  {
 	    struct display *nd;
 
-	    args[0][n] = '\0';
 	    debug1("at display matching '%s'\n", args[0]);
 	    for (display = displays; display; display = nd)
 	      {
@@ -855,15 +865,19 @@ int key;
 	    return;
 	  }
 	case '#':
-	  args[0][n--] = '\0';
+	  n--;
 	  /* FALLTHROUGH */
 	default:
 	  {
 	    struct win *nw;
+	    int ch;
 
 	    n++; 
+	    ch = args[0][n];
+	    args[0][n] = '\0';
 	    if (!*args[0] || (i = WindowByNumber(args[0])) < 0)
 	      {
+	        args[0][n] = ch;      /* must restore string in case of bind */
 	        /* try looping over titles */
 		for (fore = windows; fore; fore = nw)
 		  {
@@ -895,6 +909,7 @@ int key;
 	      }
 	    else if (i < MAXWIN && (fore = wtab[i]))
 	      {
+	        args[0][n] = ch;      /* must restore string in case of bind */
 	        debug2("AT window %d (%s)\n", fore->w_number, fore->w_title);
 		if (fore->w_display)
 		  display = fore->w_display;
@@ -1572,6 +1587,12 @@ int key;
     case RC_DEFWRAP:
       (void)ParseOnOff(act, &nwin_default.wrap);
       break;
+    case RC_DEFC1:
+      (void)ParseOnOff(act, &nwin_default.c1);
+      break;
+    case RC_DEFGR:
+      (void)ParseOnOff(act, &nwin_default.gr);
+      break;
     case RC_DEFMONITOR:
       if (ParseOnOff(act, &n) == 0)
         nwin_default.monitor = (n == 0) ? MON_OFF : MON_ON;
@@ -2138,7 +2159,7 @@ int key;
 	{
 	  if (args[i] == 0)
 	    break;
-	  if (strcmp(args[i], "jis") == 0)
+	  if (strcmp(args[i], "jis") == 0 || strcmp(args[i], "off") == 0)
 	    n = 0;
 	  else if (strcmp(args[i], "euc") == 0)
 	    n = EUC;
@@ -2155,35 +2176,21 @@ int key;
 	    D_kanji = n;
 	}
       if (fore)
+        ResetCharsets(fore);
+      break;
+    case RC_DEFKANJI:
+      if (strcmp(*args, "jis") == 0 || strcmp(*args, "off") == 0)
+	n = 0;
+      else if (strcmp(*args, "euc") == 0)
+	n = EUC;
+      else if (strcmp(*args, "sjis") == 0)
+	n = SJIS;
+      else
 	{
-	  switch(fore->w_kanji)
-	    {
-	    case 0:
-	    case SJIS:
-	      fore->w_charsets[0] = ASCII;
-	      fore->w_charsets[1] = KANA;
-	      fore->w_charsets[2] = ASCII;
-	      fore->w_Charset = 0;
-	      fore->w_CharsetR = 1;
-	      fore->w_gr = 1;
-	      fore->w_c1 = 0;
-	      break;
-	    case EUC:
-	      fore->w_charsets[0] = ASCII;
-	      fore->w_charsets[1] = KANJI;
-	      fore->w_charsets[2] = KANA;
-	      fore->w_Charset = 0;
-	      fore->w_CharsetR = 1;
-	      fore->w_gr = 1;
-	      fore->w_c1 = 1;
-	      break;
-	    default:
-	      break;
-	    }
-	  fore->w_ss = 0;
-	  fore->w_Font = fore->w_charsets[fore->w_Charset];
-	  fore->w_FontR = fore->w_charsets[fore->w_CharsetR];
+	  Msg(0, "defkanji: illegal argument (%s)", *args);
+	  break;
 	}
+      nwin_default.kanji = n;
       break;
 #endif
     case RC_PRINTCMD:
