@@ -62,6 +62,10 @@ RCS_ID("$Id: screen.c,v 1.23 1994/05/31 12:32:51 mlschroe Exp $ FAU")
 # include <sys/pty.h>
 #endif /* ISC */
 
+#if (defined(AUX) || defined(_AUX_SOURCE)) && defined(POSIX)
+# include <compat.h>
+#endif
+
 #include "screen.h"
 
 #include "patchlevel.h"
@@ -117,6 +121,7 @@ static void  WindowDied __P((struct win *));
 extern char Password[];
 #endif
 
+int nversion;	/* numerical version, used for secondary DA */
 
 /* the attacher */
 struct passwd *ppp;
@@ -167,7 +172,7 @@ int MasterPid;
 int real_uid, real_gid, eff_uid, eff_gid;
 int default_startup;
 int slowpaste;
-int ZombieKey;
+int ZombieKey_destroy, ZombieKey_resurrect;
 
 #ifdef NETHACK
 int nethackflag = 0;
@@ -336,6 +341,10 @@ char **av;
   char *sockp;
 #endif
 
+#if (defined(AUX) || defined(_AUX_SOURCE)) && defined(POSIX)
+  setcompat(COMPAT_POSIX|COMPAT_BSDPROT); /* turn on seteuid support */
+#endif
+
   /*
    *  First, close all unused descriptors
    *  (otherwise, we might have problems with the select() call)
@@ -355,6 +364,7 @@ char **av;
 #endif
   sprintf(version, "%d.%.2d.%.2d%s (%s) %s", REV, VERS,
 	  PATCHLEVEL, STATE, ORIGIN, DATE);
+  nversion = REV * 10000 + VERS * 100 + PATCHLEVEL;
   debug2("-- screen debug started %s (%s)\n", *av, version);
 #ifdef POSIX
   debug("POSIX\n");
@@ -1755,7 +1765,7 @@ static void
 WindowDied(p)
 struct win *p;
 {
-  if (ZombieKey)
+  if (ZombieKey_destroy)
     {
       char buf[100], *s;
       time_t now;
@@ -1955,7 +1965,7 @@ DoWait()
 		    }
 #endif
 		  /* Try to restart process */
-# ifdef NETHACK	
+# ifdef NETHACK
                   if (nethackflag)
 		    Msg(0, "You regain consciousness.");
 		  else
