@@ -210,12 +210,18 @@ char *match;
       *slisttail = sent;
       slisttail = &sent->next;
       nfound++;
-      if ((s = MakeClientSocket(0)) == -1)
+      s = MakeClientSocket(0);
+#ifdef USE_SETEUID
+      /* MakeClientSocket sets ids back to eff */
+      xseteuid(real_uid);
+      xsetegid(real_gid);
+#endif
+      if (s == -1)
 	{
 	  sent->mode = -3;
 	  /* Unreachable - it is dead if we detect that it's local
            * or we specified a match
-            */
+           */
 	  n = name + strlen(name) - 1;
 	  while (n != name && *n != '.')
 	    n--;
@@ -237,10 +243,20 @@ char *match;
       /* Shall we connect ? */
       mode &= 0776;
 
-      if ((dflag && mode != 0700) ||
-          (!dflag && ((rflag && mode != 0600) ||
-                     (xflag && mode != 0600 && mode != 0700) ||
-		     (!rflag && !xflag))))
+     /*
+      * mode 600: socket is detached.
+      * mode 700: socket is attached.
+      * xflag implies rflag here.
+      *
+      * fail, when socket mode mode is not 600 or 700
+      * fail, when we want to detach, but it already is.
+      * fail, when we only want to attach, but mode 700 and not xflag.
+      * fail, if none of dflag, rflag, xflag is set.
+      */
+     if ((mode != 0700 && mode != 0600) ||
+        (dflag && mode == 0600) ||
+        (!dflag && rflag && mode == 0700 && !xflag) ||
+        (!dflag && !rflag && !xflag))
 	{
 	  close(s);
 	  continue;
@@ -254,6 +270,7 @@ char *match;
       else
 	close(s);
     }
+  (void)closedir(dirp);
   if (nfound && (lsflag || ngood != 1) && !quietflag)
     {
       switch(ngood)
