@@ -73,13 +73,13 @@ static char DefaultPath[] = ":/usr/ucb:/bin:/usr/bin";
 struct NewWindow nwin_undef   = 
 {
   -1, (char *)0, (char **)0, (char *)0, (char *)0, -1, -1, 
-  -1, -1, -1, -1, -1
+  -1, -1, -1, -1, -1, -1, -1, -1
 };
 
 struct NewWindow nwin_default = 
 { 
   0, 0, ShellArgs, 0, screenterm, 0, 1*FLOW_NOW, 
-  LOGINDEFAULT, DEFAULTHISTHEIGHT, MON_OFF, WLOCK_AUTO, 1
+  LOGINDEFAULT, DEFAULTHISTHEIGHT, MON_OFF, WLOCK_AUTO, 1, 1, 0, 0
 };
 
 struct NewWindow nwin_options;
@@ -99,7 +99,12 @@ struct NewWindow *def, *new, *res;
   res->histheight = new->histheight != nwin_undef.histheight ? new->histheight : def->histheight;
   res->monitor = new->monitor != nwin_undef.monitor ? new->monitor : def->monitor;
   res->wlock = new->wlock != nwin_undef.wlock ? new->wlock : def->wlock;
-  res->wrap = new->wrap != nwin_undef.wrap ? new->wlock : def->wrap;
+  res->wrap = new->wrap != nwin_undef.wrap ? new->wrap : def->wrap;
+  res->c1 = new->c1 != nwin_undef.c1 ? new->c1 : def->c1;
+  res->gr = new->gr != nwin_undef.gr ? new->gr : def->gr;
+#ifdef KANJI
+  res->kanji = new->kanji != nwin_undef.kanji ? new->kanji : def->kanji;
+#endif
 }
 
 int
@@ -107,7 +112,7 @@ MakeWindow(newwin)
 struct NewWindow *newwin;
 {
   register struct win **pp, *p;
-  register int n;
+  register int n, i;
   int f = -1;
   struct NewWindow nwin;
   int ttyflag;
@@ -159,6 +164,12 @@ struct NewWindow *newwin;
       return -1;
     }
   bzero((char *) p, (int) sizeof(struct win)); /* looks like a calloc above */
+
+  /* save the command line so that zombies can be resurrected */
+  for (i = 0; nwin.args[i] && i < MAXARGS - 1; i++)
+    p->w_cmdargs[i] = SaveStr(nwin.args[i]);
+  p->w_cmdargs[i] = 0;
+
   if (!(p->w_dlist = (struct displaylist *)malloc(sizeof(struct displaylist))))
     {
       free((char *)p);
@@ -177,7 +188,6 @@ struct NewWindow *newwin;
       return -1;
     }
 #endif
-  p->w_dupto = -1;
   p->w_winlay.l_next = 0;
   p->w_winlay.l_layfn = &WinLf;
   p->w_winlay.l_data = (char *)p;
@@ -218,7 +228,10 @@ struct NewWindow *newwin;
 #ifdef COPY_PASTE
   ChangeScrollback(p, nwin.histheight, p->w_width);
 #endif
-  ResetWindow(p);	/* sets p->w_wrap */
+#ifdef KANJI
+  p->w_kanji = nwin.kanji;
+#endif
+  ResetWindow(p);	/* sets w_wrap, w_c1, w_gr */
 
   if (ttyflag == TTY_FLAG_PLAIN)
     {
@@ -247,20 +260,18 @@ struct NewWindow *newwin;
   p->w_next = windows;
   windows = p;
 #ifdef UTMPOK
+  p->w_slot = (slot_t) -1;
 # ifdef LOGOUTOK
   debug1("MakeWindow will %slog in.\n", nwin.lflag?"":"not ");
-  if (!nwin.lflag)
-    p->w_slot = (slot_t) -1;
-  else
+  if (nwin.lflag)
 # else /* LOGOUTOK */
   debug1("MakeWindow will log in, LOGOUTOK undefined in config.h%s.\n", 
          nwin.lflag?"":" (although lflag=0)");
 # endif /* LOGOUTOK */
     {
+      p->w_slot = (slot_t) 0;
       if (display)
         SetUtmp(p);
-      else
-	p->w_slot = (slot_t) 0;
     }
 #endif
   SetForeWindow(p);
@@ -268,6 +279,66 @@ struct NewWindow *newwin;
   return n;
 }
 
+/*
+ * Resurrect a window from Zombie state. 
+ * The command vector is therefore stored in the window structure.
+ * Note: The terminaltype defaults to screenterm again, the current 
+ * working directory is lost.
+ */
+int
+RemakeWindow(p)
+struct win *p;
+{
+  int ttyflag;
+  char *TtyName;
+  int lflag, f;
+
+  lflag = nwin_default.lflag;
+  if ((f = OpenDevice(p->w_cmdargs[0], lflag, &ttyflag, &TtyName)) < 0)
+    return -1;
+
+  strncpy(p->w_tty, *TtyName ? TtyName : p->w_title, MAXSTR - 1);
+  p->w_ptyfd = f;
+
+  p->w_t.flags &= ~TTY_FLAG_PLAIN;
+  if (ttyflag == TTY_FLAG_PLAIN)
+    {
+      p->w_t.flags |= TTY_FLAG_PLAIN;	/* Just in case... */
+      WriteString(p, p->w_cmdargs[0], strlen(p->w_cmdargs[0]));
+      WriteString(p, ": ", 2);
+      WriteString(p, p->w_title, strlen(p->w_title));
+      WriteString(p, "\r\n", 2);
+      p->w_pid = 0;
+    }
+  else 
+    {
+      for (f = 0; p->w_cmdargs[f]; f++)
+	{
+	  if (f)
+	    WriteString(p, " ", 1);
+	  WriteString(p, p->w_cmdargs[f], strlen(p->w_cmdargs[f]));
+	}
+      WriteString(p, "\r\n", 2);
+      p->w_pid = ForkWindow(p->w_cmdargs, (char *)0, nwin_default.term, TtyName, p);
+      if (p->w_pid < 0)
+        return -1;
+    }
+
+#ifdef UTMPOK
+  p->w_slot = (slot_t) -1;
+  debug1("RemakeWindow will %slog in.\n", lflag ? "" : "not ");
+# ifdef LOGOUTOK
+  if (lflag)
+# endif
+    {
+      p->w_slot = (slot_t) 0;
+      if (display)
+	SetUtmp(p);
+    }
+#endif
+  return p->w_number;
+}
+
 void
 FreeWindow(wp)
 struct win *wp;
